#

##

##

##

###

###

###

    	picker queue

    	summary

    	physics

    		[ ] add to scene if >50% have voted for the scene

    	contingencies
    		# problems

    		unresponsive
    			[ ] Unresponsive voters lead to less than 50% consensus

    		ignoring
    			[ ] A picker could progam to ignore the asks of certain
    				addresses.

    		selectivism
    			[ ] A voter could always vote to approve
    				a ranked subset of pickers.